import { Page, Locator } from "@playwright/test"
import { ALERT_USER_CREATED_SUCESSFULLY_MESSAGE } from "../constants/constants"

export class AddMembershipPage {

    readonly page: Page
    readonly primaryTitle: Locator
    readonly secondaryTitle: Locator
    readonly typeOfMembership: Locator
    readonly startDate: Locator
    readonly endDate: Locator
    readonly saveButton: Locator

    readonly cancelButton: Locator
    readonly addMembershipButton: Locator

    public constructor(page: Page) {
        this.page = page;
        this.primaryTitle = this.page.getByRole('heading', { name: 'User management' })
        this.secondaryTitle = this.page.getByRole('heading', { name: 'Associate a membership to the user' })
        this.typeOfMembership = this.page.getByLabel('Type of membership')
        this.startDate = this.page.getByPlaceholder('Start date')
        this.endDate = this.page.getByPlaceholder('End date')
        this.saveButton = this.page.getByRole('button', { name: 'Save' })
        this.cancelButton = this.page.getByRole('link', { name: 'Cancel' })
    }

    async getPrimaryTitle() {
        try {
            return await this.primaryTitle.innerText();
        } catch (error) {
            console.error("Failed to get primary title:", error);
            throw error;
        }
    }

    async getSecondaryTitle() {
        try {
            return await this.secondaryTitle.innerText();
        } catch (error) {
            console.error("Failed to get secondary title:", error);
            throw error;
        }
    }

    async getTypeOfMembership() {
        try {
            return this.typeOfMembership;
        } catch (error) {
            console.error("Failed to get Type of membership:", error);
            throw error;
        }
    }

    async getStartDate() {
        try {
            return this.startDate;
        } catch (error) {
            console.error("Failed to get Start date:", error);
            throw error;
        }
    }

    async getEndDate() {
        try {
            return this.endDate;
        } catch (error) {
            console.error("Failed to get End date:", error);
            throw error;
        }
    }

    async selectSaveButton() {
        try {
            await this.saveButton.click()
        } catch (error) {
            console.error("Failed to select Save button:", error);
            throw error;
        }
    }

    async selectCancelButton() {
        try {
            await this.cancelButton.click()
        } catch (error) {
            console.error("Failed to select Cancel button:", error);
            throw error;
        }
    }

    async addUserMembership(membershipType: string, startDate: string, endDate: string) {

        try {
            await this.page.locator('alert alert-success alert-dismissible fade show mt-3').isVisible()
            await this.typeOfMembership.selectOption(membershipType)
            await this.startDate.fill(startDate);
            await this.endDate.fill(endDate);
            await this.saveButton.click();
        } catch (error) {
            console.error("Failed to add user membership:", error);
            throw error;
        }
    }

    async addNewUserMembership(membershipType: string, startDate: string, endDate: string) {

        try {
            await this.typeOfMembership.selectOption(membershipType)
            await this.startDate.fill(startDate);
            await this.endDate.fill(endDate);
            await this.saveButton.click();
        } catch (error) {
            console.error("Failed to add a new user membership:", error);
            throw error;
        }
    }


    async updateExistingUserMembership(page: Page, membershipToChange: string, newMembership: string, newStartDate: string, newEndDate: string) {

        try {
            await this.typeOfMembership.selectOption(newMembership);
            await this.startDate.fill(newStartDate);
            await this.endDate.fill(newEndDate);
            await this.saveButton.click();
        } catch (error) {
            console.error("Failed to update a user membership:", error);
            throw error;
        }
    }

    async alertUserCreationMessageIsValid(): Promise<boolean> {

        try {
            await this.page.locator('.alert.alert-success.alert-dismissible').waitFor({ state: 'visible', timeout: 5000 });
            // If the success message is found and visible, retrieve its text content
            const message = await this.page.locator('.alert.alert-success.alert-dismissible').textContent();

            // Compare the retrieved text with the expected error message
            return message?.trim() === ALERT_USER_CREATED_SUCESSFULLY_MESSAGE;

        } catch (error) {
            console.error('Failed to check success message:', error);
            throw error;
        }
    }
}

