import { type Page, type Locator } from '@playwright/test';

export class EncryptionKeyPage {
  readonly page: Page;
  readonly primaryTitle: Locator
  readonly secondaryTitle: Locator
  readonly keyForEncryption: Locator
  readonly saveButton: Locator

  public constructor(page: Page) {
    this.page = page;
    this.page = page;
    this.primaryTitle = page.getByRole('heading', { name: 'Encryption Key' });
    this.secondaryTitle = page.getByRole('heading', { name: 'Encryption Key' });
    this.keyForEncryption = page.getByPlaceholder('Key for encrypt the secrets');
    this.saveButton = page.getByRole('button', { name: 'Save' });
  }

  async getPrimaryTitle() {
    try {
      return await this.primaryTitle.innerText();
    } catch (error) {
      console.error("Failed to get primary title:", error);
      throw error;
    }
  }

  async getSecondaryTitle() {
    try {
      return await this.secondaryTitle.innerText();
    } catch (error) {
      console.error("Failed to get secondary title:", error);
      throw error;
    }
  }

  async getKeyForEncryption() {
    try {
      return this.keyForEncryption;
    } catch (error) {
      console.error("Failed to get key for encryption:", error);
      throw error;
    }
  }

  async getSaveButton() {
    try {
      return this.saveButton;
    } catch (error) {
      console.error("Failed to get save button:", error);
      throw error;
    }
  }

  async enterKey(key: string) {
    try {
      (await this.getKeyForEncryption()).click();
      (await this.getKeyForEncryption()).fill(key);
    } catch (error) {
      console.error('Failed to enter the encryption key:', error);
      throw error;
    }
  }

  async clickSaveButton() {
    try {
      (await this.getSaveButton()).click();
    } catch (error) {
      console.error('Failed to click save button:', error);
      throw error;
    }
  }

}