import { Page, Locator } from "@playwright/test";
import { getMembershipTypeById } from "../utils";

export class MembershipSectionPage {
  readonly page: Page;
  readonly membershipTitle: Locator;
  readonly fromTitle: Locator;
  readonly toTitle: Locator;
  readonly addMembershipButton: Locator;

  constructor(page: Page) {
    this.page = page;
    this.membershipTitle = page.getByRole('button', { name: 'Membership' });
    this.fromTitle = page.getByRole('button', { name: 'From' });
    this.toTitle = page.getByRole('button', { name: 'To' });
    this.addMembershipButton = this.page.getByRole('link', { name: 'Add membership' })
  }

  async getMembershipTitle() {
    try {
      return this.membershipTitle;
    } catch (error) {
      console.error("Failed to get Membership title:", error);
      throw error;
    }
  }

  async getFromTitle() {
    try {
      return this.fromTitle;
    } catch (error) {
      console.error("Failed to getFrom title:", error);
      throw error;
    }
  }

  async getToTitle() {
    try {
      return this.toTitle;
    } catch (error) {
      console.error("Failed to get To title:", error);
      throw error;
    }
  }

  async getAddMembershipButton() {
    try {
      return this.addMembershipButton;
    } catch (error) {
      console.error("Failed to get Add Membership button:", error);
      throw error;
    }
  }

  async selectAddMembershipButton() {
    try {
      return (await this.getAddMembershipButton()).click();
    } catch (error) {
      console.error("Failed to click Add Membership button:", error);
      throw error;
    }
  }

  async membershipExist(page: Page, membershipType: string): Promise<boolean> {
    try {
      const ms = getMembershipTypeById(membershipType);
      const membershipExists = await page.$$eval('tr', (rows, ms) => {
        // Find the row with membershipType
        const membershipRow = rows.find(row => Array.from(row.children).some((child: Node & ChildNode) => (child as HTMLElement).innerText === ms));
        return !!membershipRow;
      }, ms);
      return membershipExists;

    } catch (error) {
      console.error("The selected membershipType does not exist: ", error);
      throw error;
    }
  }


  async gotoModifyMembershipPage(page: Page, membershipToChange: string) {
    try {
      const ms = getMembershipTypeById(membershipToChange);
      await page.$$eval('tr', (rows, ms) => {
        // Find the row with membershipType
        const membershipRow = rows.find(row => Array.from(row.children).some((child: Node & ChildNode) => (child as HTMLElement).innerText === ms));

        // Get the "Edit" button from the row and click it   
        if (membershipRow) {
          const editButton = membershipRow.querySelector('a[title="Edit"]') as HTMLElement;
          if (editButton) {
            editButton.click();
          }
        } else {
          throw new Error(`Membership row with membershipType ${ms} not found.`);
        }
      }, ms);

    } catch (error) {
      console.error("The selected membershipType does not exist: ", error);
    }
  }

  async gotoDeleteSpecificMembership(page: Page, membershipType: string) {
    try {
      const ms = getMembershipTypeById(membershipType)
      await page.$$eval('tr', (rows, ms) => {
        // Find the row with membershipType
        const membershipRow = rows.find(row => Array.from(row.children).some((child: Node & ChildNode) => (child as HTMLElement).innerText === ms));

        // Get the "Delete" button from the row and click it
        if (membershipRow) {
          const deleteButton = membershipRow.querySelector('a[title="Delete"]') as HTMLElement;
          if (deleteButton) {
            deleteButton.click();
          }
        } else {
          throw new Error(`Membership row with membershipType ${ms} not found.`);
        }
      }, ms);
    } catch (error) {
      console.error("The selected membershipType does not exist: ", error);
    }
  }
}
