import { Page, Locator, expect } from "@playwright/test"
import { ALERT_FILE_IMPORTED_SUCCESSFULLY } from "../constants/constants"

export class ViewImportedDataPage {

    readonly page: Page
    readonly primaryTitle: Locator
    readonly secondaryTitle: Locator
    readonly dateTitle: Locator
    readonly fileTitle: Locator
    readonly successTitle: Locator
    readonly importDataButton: Locator

    constructor(page: Page) {
        this.page = page;
        this.primaryTitle = page.getByRole('heading', { name: 'Data file management' });
        this.secondaryTitle = page.getByRole('heading', { name: 'Import data' });
        this.dateTitle = page.getByRole('link', { name: 'Date' })
        this.fileTitle = page.getByRole('link', { name: 'File' })
        this.successTitle = page.getByRole('link', { name: 'Success' })
        this.importDataButton = page.getByRole('link', { name: 'Import data ' })
    }

    async getPrimaryTitle() {
        try {
            return await this.primaryTitle.innerText();
        } catch (error) {
            console.error("Failed to get primary title:", error);
            throw error;
        }
    }

    async getSecondaryTitle() {
        try {
            return await this.secondaryTitle.innerText();
        } catch (error) {
            console.error("Failed to get secondary title:", error);
            throw error;
        }
    }


    async getDateTitle() {

        try {
            return this.dateTitle;
        } catch (error) {
            console.error("Failed to get Data title:", error);
            throw error;
        }
    }

    async getFileTitle() {
        try {
            return this.fileTitle;
        } catch (error) {
            console.error("Failed to get File title:", error);
            throw error;
        }
    }

    async getSuccessTitle() {
        try {
            return this.successTitle;
        } catch (error) {
            console.error("Failed to get Success title:", error);
            throw error;
        }
    }

    async getImportDataButton() {
        try {
            return this.importDataButton;
        } catch (error) {
            console.error("Failed to get Import Data button:", error);
            throw error;
        }
    }

    async gotoImportDataPage() {
        try {
            (await this.getImportDataButton()).click();
        } catch (error) {
            console.error("Failed to go to import data page:", error);
            throw error;
        }
    }

    async orderTableByDate() {
        (await this.getDateTitle()).click();
    }

    async fileIsAvailableInView(fileName: string): Promise<boolean> {

        try {
            // Wait for the table to appear and contain at least one row
            await this.page.waitForFunction(() => document.querySelectorAll('tr').length > 0, { timeout: 10000 });

            const fileExists = await this.page.$$eval('td:nth-child(2)', (tds, fileName) => {
                return tds.some(td => (td as HTMLElement).innerText === fileName);
            }, fileName);
            return fileExists;

        } catch (error) {
            console.error("A problem while loading the list of files.", error);
            throw error;
        }
    }

    async isFileSuccessfullyLoaded(fileName: string): Promise<boolean> {
        try {
            const row = this.page.locator(`tr:has-text('${fileName}')`);

            if (!row) {
                console.log(`No row found with file value: ${fileName}`);
                return false;
            }
            const thirdCell = row.locator('td:nth-child(3)');
            if (thirdCell) {
                const tickOrCross = await thirdCell.textContent();
                if (tickOrCross === '✔') {
                    return true;
                } else if (tickOrCross === '✘') {
                    return false;
                }
            }
            return false;
        } catch (error) {
            console.error('Error occurred:', error);
            return false;
        }
    }

    async alertFileImportedSuccessfully(): Promise<boolean> {
        try {
            await this.page.locator('.alert.alert-success.alert-dismissible').waitFor({ state: 'visible', timeout: 5000 });

            // If the success message is found and visible, retrieve its text content
            const message = await this.page.locator('.alert.alert-success.alert-dismissible').textContent();

            // Compare the retrieved text with the expected error message
            return message?.trim() === ALERT_FILE_IMPORTED_SUCCESSFULLY;

        } catch (error) {
            console.error('Failed to check for successful file import alert:', error);
            throw error;
        }
    }
}