import { type Page, type Locator } from '@playwright/test';

export class DataProtectionPage {
  readonly page: Page;
  readonly primaryTitle: Locator
  readonly secondaryTitle: Locator
  readonly acceptPrivacyCheckBox: Locator
  readonly acceptLegalCheckBox: Locator
  readonly acceptCookiesCheckBox: Locator
  readonly confirmButton: Locator



  public constructor(page: Page) {
    this.page = page;
    this.primaryTitle = page.getByRole('heading', { name: 'Data protection' });
    this.secondaryTitle = page.getByRole('heading', { name: ' Terms and Conditions' });
    this.acceptPrivacyCheckBox = page.locator('#id_accept_privacy');
    this.acceptLegalCheckBox = page.locator('#id_accept_legal');
    this.acceptCookiesCheckBox = page.locator('#id_accept_cookies');
    this.confirmButton = page.getByRole('link', { name: 'Confirm' });
  }

  async getPrimaryTitle() {
    try {
      return await this.primaryTitle.innerText();
    } catch (error) {
      console.error("Failed to get primary title:", error);
      throw error;
    }
  }

  async getSecondaryTitle() {
    try {
      return await this.secondaryTitle.innerText();
    } catch (error) {
      console.error("Failed to get secondary title:", error);
      throw error;
    }
  }

  async checkAcceptPrivacyCheckBox() {
    try {
      return this.acceptPrivacyCheckBox.check();
    } catch (error) {
      console.error("Failed to check privacy box:", error);
      throw error;
    }
  }

  async checkAcceptCookiesCheckBox() {
    try {
      return this.acceptCookiesCheckBox.check();
    } catch (error) {
      console.error("Failed to check cookies box:", error);
      throw error;
    }
  }

  async checkAcceptLegalCheckBox() {
    try {
      return this.acceptLegalCheckBox.check();
    } catch (error) {
      console.error("Failed to check legal box:", error);
      throw error;
    }
  }

  async getConfirmButton() {
    try {
      return this.confirmButton;
    } catch (error) {
      console.error("Failed to get save button:", error);
      throw error;
    }
  }

  
  async clickConfirmButton() {
    try {
      (await this.getConfirmButton()).click();
    } catch (error) {
      console.error('Failed to click save button:', error);
      throw error;
    }
  }

}