import { type Page, type Locator, expect } from '@playwright/test';
import { ERROR_INCORRECT_EMAIL_PASSWORD } from '../constants/constants';

export class LogInPage {
  readonly page: Page;
  readonly emailInputLocator: Locator
  readonly passwordInputLocator: Locator
  readonly signInButtonLocator: Locator

  public constructor(page: Page) {
    this.page = page;
    this.emailInputLocator = page.getByPlaceholder('Email address')
    this.passwordInputLocator = page.getByPlaceholder('Password')
    this.signInButtonLocator = page.getByRole('button', { name: 'Log in' })
  }
  async visit(site: string) {
    try {
      await this.page.goto(site);
    } catch (error) {
      console.error('Failed to navigate to the site:', error);
      throw error;
    }
  }
  async login(email: string, password: string) {
    try {
      await this.emailInputLocator.fill(email);
      await this.passwordInputLocator.fill(password);
      await this.signInButtonLocator.click();
    } catch (error) {
      console.error('Failed to login:', error);
      throw error;
    }
  }

  async visitForgotPassword(site: string) {
    try {
      await this.page.goto(site);
    } catch (error) {
      console.error('Failed to navigate to the forgot password page:', error);
      throw error;
    }
  }

  async errorMessageIsValid() {
    try {
      await this.page.locator('.well.well-small.text-error').waitFor({ state: 'visible', timeout: 5000 });
      // If the error message is found and visible, retrieve its text content
      const errorText = await this.page.locator('.well.well-small.text-error').textContent();

      // Compare the retrieved text with the expected error message
      return errorText?.trim() === ERROR_INCORRECT_EMAIL_PASSWORD;
    } catch (error) {
      console.error('Failed to check error message:', error);
      throw error;
    }

  }
}