import { Page, Locator } from "@playwright/test"
import { initialize_with_undefined_values, setCredentialValues } from "../steps";

export class ViewCredentialPage {

  readonly page: Page
  readonly primaryTitle: Locator
  readonly secondaryTitle: Locator
  readonly requestCredentialButton: Locator

  constructor(page: Page) {
    this.page = page;
    this.primaryTitle = page.getByRole('heading', { name: 'My wallet' });
    this.requestCredentialButton = page.getByRole('link', { name: 'Request credential' });

  }
  async getPrimaryTitle() {
    try {
      return await this.primaryTitle.innerText();
    } catch (error) {
      console.error("Failed to get primary title:", error);
      throw error;
    }
  }

  async getRequestCredentialButton() {
    try {
      return this.requestCredentialButton;
    } catch (error) {
      console.error("Failed to get request credential button:", error);
      throw error;
    }
  }

  async clickRequestCredentialButton() {
    try {
      return (await this.getRequestCredentialButton()).click();
    } catch (error) {
      console.error("Failed to get click credential button:", error);
      throw error;
    }
  }


  async buildACredentialFromInputValues(credentialType: string) {

    try {
      const elementsWithLabel = await this.page.locator('.col-3 strong').all();
      const elementsWithValue = await this.page.locator('.col.bg-light.text-secondary').all();
      

      let credential = initialize_with_undefined_values(credentialType);

      let labels: string[] = [];
      let values: string[] = [];

      for (let i = 0; i < elementsWithLabel.length; i++) {
        let label = await elementsWithLabel[i].textContent()
        if (label) label = label.trim().replace(/:$/, '');
        let value = await elementsWithValue[i].textContent()
        if (value) value = value.trim();
        if (value != null && label != null && label != 'Id' && label != "Issuance date" && label != "Status") {
          labels.push(label);
          values.push(value);
        } else {
          if (label === "Status"){
            credential.status = value;
          }
        }
      }

      credential.credentialSubject = setCredentialValues(labels, values, credentialType);
      return credential;
    } catch (error) {
      console.error("Failed to build the credential from input values:", error);
      throw error;
    }

  }//end function


}
