import { Page, Locator } from "@playwright/test"
import { ISSUED_ST } from "../constants/constants"

export class ViewMyCredentialsPage {

    readonly page: Page
    readonly primaryTitle: Locator
    readonly secondaryTitle: Locator
    readonly typeTitle: Locator
    readonly detailsTitle: Locator
    readonly issuedOnTitle: Locator
    readonly statusTitle: Locator
    readonly viewCredentialButton: Locator


    constructor(page: Page) {
        this.page = page;
        this.primaryTitle = page.getByRole('heading', { name: 'My wallet' });
        this.secondaryTitle = page.getByRole('heading', { name: 'Credential management' });
        this.typeTitle = page.getByRole('link', { name: 'Type' })
        this.detailsTitle = page.getByRole('link', { name: 'Details' })
        this.issuedOnTitle = page.getByRole('link', { name: 'Issued on' })
        this.statusTitle = page.getByRole('link', { name: 'Status' })
        this.viewCredentialButton = page.getByRole('link', { name: '' })

    }
    async getPrimaryTitle() {
        try {
            return await this.primaryTitle.innerText();
        } catch (error) {
            console.error("Failed to get primary title:", error);
            throw error;
        }
    }

    async getSecondaryTitle() {
        try {
            return await this.secondaryTitle.innerText();
        } catch (error) {
            console.error("Failed to get secondary title:", error);
            throw error;
        }
    }


    async getTypeTitle() {
        try {
            return this.typeTitle;
        } catch (error) {
            console.error("Failed to get Type title:", error);
            throw error;
        }
    }

    async getDetailsTitle() {
        try {
            return this.detailsTitle;
        } catch (error) {
            console.error("Failed to get Details title:", error);
            throw error;
        }
    }

    async getIssuedOnTitle() {
        try {
            return this.issuedOnTitle;
        } catch (error) {
            console.error("Failed to get Issue On title:", error);
            throw error;
        }
    }

    async getStatusTitle() {
        try {
            return this.statusTitle;
        } catch (error) {
            console.error("Failed to get Issue On title:", error);
            throw error;
        }
    }


    async orderTableByType() {
        (await this.getTypeTitle()).click();
    }

    async orderTableByIssuedOn() {
        (await this.getIssuedOnTitle()).click();
    }

    async gotoViewCredentialPage(type: string, status: string) {
        // Locator for all rows
        const rowLocator = this.page.locator('tr');

        // Rows with the first column having the specified type
        const typeFilteredRows = rowLocator.filter({ hasText: type });

        // Rows with the fourth column having the specified status
        //const statusFilteredRows = typeFilteredRows.filter({ hasText: status });
        // Manually filter rows based on the fourth column's text content
        let statusFilteredRows = [];
        for (const row of await typeFilteredRows.all()) {
            const fourthColumnText = await row.locator('td:nth-child(4)').textContent();
            if (fourthColumnText === status) {
                await row.locator('i.bi.bi-eye').click();
                break;
            }
        }
    }

    async credentialExistInMyCredentials(type: string, status: string): Promise<boolean> {
        // Locator for all rows
        const rowLocator = this.page.locator('tr');

        // Rows with the first column having the specified type
        const typeFilteredRows = rowLocator.filter({ hasText: type });

        // Rows with the fourth column having the specified status
        const statusFilteredRows = typeFilteredRows.filter({ hasText: status });

        // only the rows matching both criteria
        // Check if the row exists
        if (await statusFilteredRows.count() > 0) {
            return true;
        } else {
            console.log(`No row found with type '${type}' and status '${status}'.`);
            return false;
        }

    }
}